import React, { useEffect, useState } from 'react';
import { connect } from 'umi';
import { notification, Tabs } from 'antd';
import { PageContainer } from '@ant-design/pro-layout';
import Container from '@/components/Container';
import request from '@/utils/request';
import PostForm from './components/Form';
import Answer from './components/Answer';

const { TabPane } = Tabs;

const PostEdit = (props) => {
  const { id } = props.location.query;
  const [loading, setLoading] = useState(false);
  const [post, setPost] = useState({});

  const handleFormChange = (newPost) => {
    setPost(newPost);
  };

  useEffect(() => {
    setLoading(true);
    request(`/post/${id}`)
      .then((res) => {
        setPost(res);
        setLoading(false);
      })
      .catch((e) => {
        setLoading(false);
        notification.error({ message: e.message });
      });
  }, [id]);

  useEffect(() => {
    if (!props.typeList || !props.typeList.length) {
      props.dispatch({
        type: 'post/getTypeList',
        payload: { pageSize: 999 },
      });
    }
  }, [props]);

  return (
    <PageContainer>
      <Container>
        <Tabs>
          <TabPane tab="科普信息" key="1">
            <Container loading={loading}>
              <PostForm post={post} typeList={props.typeList} onChange={handleFormChange} />
            </Container>
          </TabPane>
          <TabPane tab="题库设置" key="2">
            <Container>
              <Answer />
            </Container>
          </TabPane>
        </Tabs>
      </Container>
    </PageContainer>
  );
};

export default connect((s) => ({
  typeList: s.post.typeList,
}))(PostEdit);
